/******************************************************
*
*  Copyright:    Infinetix Incorporated, 2001
*
*  Program File: saa7118.cpp
*  Author:       Dan Parker
*
*  Description:  This file contains the Csaa7118 class
*		 member functions.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
*******************************************************/

#include "saa7118.h"

#define FALSE              0
#define TRUE               1
#define SAA7118_ADDRESS    0x21

Csaa7118::Csaa7118(void) : Ci2cDev(SAA7118_ADDRESS)
{
}

Csaa7118::~Csaa7118(void)
{
}

int Csaa7118::read( int subaddr, int size, unsigned char *data)
{
   int result = FALSE;
   int index = 0;

   index = 0;
   if( subaddr < 0xF0 )
      do
      {
         result = I2cRead( (subaddr+index), 1, &data[index] );
         ++index;
      } while( (index < size) && result );

   return result;
}

int Csaa7118::write( unsigned char *data, int size )
{
   int result = FALSE;
   int index = 0;
   static int WriteBlock[8] = {
      0x01, 0x1D,
      0x20, 0x5F,
      0x63, 0x8E,
      0x90, 0xEF
   };


   while( (index < 8) && !result )
   {
      if( data[0] >= WriteBlock[index] )
         if( (data[0] + size - 2) <= WriteBlock[index+1] )
            result = TRUE;
      index += 2;
   }
   
   if( result == TRUE )
      result = I2cWrite( data, size );

   return result;
}
