/******************************************************
*
*  Copyright:    Infinetix Incorporated, 2001
*
*  Program File: saa7118setup.cpp
*  Author:       Dan Parker
*
*  Description:  This program sets up the Phillips
*                SAA7118 video decoder chip.
*
*******************************************************/

/* Standard C library includes                        */
#include <stdio.h>
#include <stdlib.h>

/* SAA7118 class include                              */
#include "saa7118.h"

#define FALSE       0
#define TRUE        1
#define PROG_TBL1_SZ 174
#define PROG_TBL2_SZ 174
#define PROG_TBL3_SZ 174
#define PROG_TBL4_SZ 174
#define PROG_TBL5_SZ 174
#define PROG_TBL6_SZ 174
#define PROG_TBL7_SZ 174
#define PROG_TBL8_SZ 174
#define PROG_TBL9_SZ 190

typedef unsigned char item[2];

item ProgTable1[PROG_TBL1_SZ] = {
   {0x01, 0x08},
   {0x02, 0xc0},
   {0x03, 0x30},
   {0x04, 0x40},
   {0x05, 0xd0},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x40},
   {0x0a, 0x7d},
   {0x0b, 0x41},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x0b},
   {0x0f, 0x0f},
   {0x10, 0x0e},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x10},
   {0x25, 0x10},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x48},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x00},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x00},
   {0x95, 0x00},
   {0x96, 0xd0},
   {0x97, 0x02},
   {0x98, 0x0f},
   {0x99, 0x00},
   {0x9a, 0xf4},
   {0x9b, 0x00},
   {0x9c, 0xd0},
   {0x9d, 0x02},
   {0x9e, 0xf4},
   {0x9f, 0x00},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x20},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x20},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable2[PROG_TBL2_SZ] = {
   {0x01, 0x08},
   {0x02, 0xc0},
   {0x03, 0x30},
   {0x04, 0x40},
   {0x05, 0xd0},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x80},
   {0x0a, 0x7d},
   {0x0b, 0x41},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x0a},
   {0x0f, 0x0f},
   {0x10, 0x06},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x10},
   {0x25, 0x10},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x48},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x00},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x00},
   {0x95, 0x00},
   {0x96, 0xd0},
   {0x97, 0x02},
   {0x98, 0x0f},
   {0x99, 0x00},
   {0x9a, 0xf4},
   {0x9b, 0x00},
   {0x9c, 0xd0},
   {0x9d, 0x02},
   {0x9e, 0xf4},
   {0x9f, 0x00},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x20},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x20},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable3[PROG_TBL3_SZ] = {
   {0x01, 0x08},
   {0x02, 0xc0},
   {0x03, 0x30},
   {0x04, 0x40},
   {0x05, 0xd0},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x00},
   {0x0a, 0x7d},
   {0x0b, 0x41},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x02},
   {0x0f, 0x0f},
   {0x10, 0x06},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x10},
   {0x25, 0x10},
   {0x29, 0x48},
   {0x2a, 0x80},
   {0x2b, 0x48},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0xe0},
   {0x90, 0x00},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x00},
   {0x95, 0x00},
   {0x96, 0xd0},
   {0x97, 0x02},
   {0x98, 0x0f},
   {0x99, 0x00},
   {0x9a, 0xf4},
   {0x9b, 0x00},
   {0x9c, 0xd0},
   {0x9d, 0x02},
   {0x9e, 0xf4},
   {0x9f, 0x00},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x20},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x20},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable4[PROG_TBL4_SZ] = {
   {0x01, 0x07},
   {0x02, 0xc0},
   {0x03, 0x32},
   {0x04, 0x40},
   {0x05, 0x2a},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x40},
   {0x0a, 0x80},
   {0x0b, 0x44},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x0b},
   {0x0f, 0x0f},
   {0x10, 0x0e},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x2a},
   {0x25, 0x2a},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x44},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x40},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x12},
   {0x95, 0x00},
   {0x96, 0xbc},
   {0x97, 0x02},
   {0x98, 0x1a},
   {0x99, 0x00},
   {0x9a, 0x1a},
   {0x9b, 0x01},
   {0x9c, 0xbc},
   {0x9d, 0x02},
   {0x9e, 0x18},
   {0x9f, 0x01},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x01},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x01},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable5[PROG_TBL5_SZ] = {
   {0x01, 0x07},
   {0x02, 0xc0},
   {0x03, 0x32},
   {0x04, 0x40},
   {0x05, 0x2a},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x80},
   {0x0a, 0x80},
   {0x0b, 0x44},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x0a},
   {0x0f, 0x0f},
   {0x10, 0x06},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x2a},
   {0x25, 0x2a},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x44},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x40},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x12},
   {0x95, 0x00},
   {0x96, 0xbc},
   {0x97, 0x02},
   {0x98, 0x1a},
   {0x99, 0x00},
   {0x9a, 0x1a},
   {0x9b, 0x01},
   {0x9c, 0xbc},
   {0x9d, 0x02},
   {0x9e, 0x18},
   {0x9f, 0x01},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x01},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x01},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable6[PROG_TBL6_SZ] = {
   {0x01, 0x07},
   {0x02, 0xc0},
   {0x03, 0x32},
   {0x04, 0x90},
   {0x05, 0x2a},
   {0x06, 0x4f},
   {0x07, 0x00},
   {0x08, 0x98},
   {0x09, 0x80},
   {0x0a, 0x80},
   {0x0b, 0x44},
   {0x0c, 0x40},
   {0x0d, 0x00},
   {0x0e, 0x0a},
   {0x0f, 0x0f},
   {0x10, 0x06},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x03},
   {0x24, 0x2a},
   {0x25, 0x2a},
   {0x29, 0x40},
   {0x2a, 0x80},
   {0x2b, 0x44},
   {0x2c, 0x40},
   {0x2d, 0x00},
   {0x2e, 0x40},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x21},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x40},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x12},
   {0x95, 0x00},
   {0x96, 0xbc},
   {0x97, 0x02},
   {0x98, 0x1a},
   {0x99, 0x00},
   {0x9a, 0x1a},
   {0x9b, 0x01},
   {0x9c, 0xbc},
   {0x9d, 0x02},
   {0x9e, 0x18},
   {0x9f, 0x01},
   {0xa0, 0x01},
   {0xa1, 0x00},
   {0xa2, 0x00},
   {0xa4, 0x80},
   {0xa5, 0x40},
   {0xa6, 0x40},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x04},
   {0xb2, 0x00},
   {0xb3, 0x04},
   {0xb4, 0x00},
   {0xb8, 0x01},
   {0xb9, 0x21},
   {0xba, 0x01},
   {0xbb, 0x01},
   {0xbc, 0x01},
   {0xbd, 0x21},
   {0xbe, 0x01},
   {0xbf, 0x01},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable7[PROG_TBL7_SZ] = {
   {0x01, 0x08},
   {0x02, 0xc0},
   {0x03, 0x33},
   {0x04, 0x00},
   {0x05, 0x00},
   {0x06, 0xeb},
   {0x07, 0xe0},
   {0x08, 0x98},
   {0x09, 0x50},
   {0x0a, 0x7a},
   {0x0b, 0x44},
   {0x0c, 0x43},
   {0x0d, 0x00},
   {0x0e, 0x09},
   {0x0f, 0x40},
   {0x10, 0x0e},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x00},
   {0x24, 0xfb},
   {0x25, 0xef},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x44},
   {0x2c, 0x44},
   {0x2d, 0x00},
   {0x2e, 0x00},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x01},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x41},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x05},
   {0x95, 0x00},
   {0x96, 0xd0},
   {0x97, 0x02},
   {0x98, 0x11},
   {0x99, 0x00},
   {0x9a, 0xf2},
   {0x9b, 0x00},
   {0x9c, 0xd0},
   {0x9d, 0x02},
   {0x9e, 0x78},
   {0x9f, 0x00},
   {0xa0, 0x02},
   {0xa1, 0x01},
   {0xa2, 0x61},
   {0xa4, 0x80},
   {0xa5, 0x1e},
   {0xa6, 0x1c},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x08},
   {0xb2, 0x00},
   {0xb3, 0x08},
   {0xb4, 0x01},
   {0xb8, 0x2a},
   {0xb9, 0x10},
   {0xba, 0x1a},
   {0xbb, 0x00},
   {0xbc, 0x2a},
   {0xbd, 0x10},
   {0xbe, 0x1a},
   {0xbf, 0x00},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable8[PROG_TBL8_SZ] = {
   {0x01, 0x08},
   {0x02, 0xc0},
   {0x03, 0x33},
   {0x04, 0x00},
   {0x05, 0x00},
   {0x06, 0xeb},
   {0x07, 0xe0},
   {0x08, 0x98},
   {0x09, 0x50},
   {0x0a, 0x7a},
   {0x0b, 0x44},
   {0x0c, 0x43},
   {0x0d, 0x00},
   {0x0e, 0x09},
   {0x0f, 0x40},
   {0x10, 0x0e},
   {0x11, 0x00},
   {0x12, 0xcf},
   {0x13, 0x80},
   {0x14, 0x14},
   {0x15, 0x11},
   {0x16, 0xfe},
   {0x17, 0xd8},
   {0x18, 0x40},
   {0x19, 0x80},
   {0x23, 0x00},
   {0x24, 0xfb},
   {0x25, 0xef},
   {0x29, 0x00},
   {0x2a, 0x80},
   {0x2b, 0x44},
   {0x2c, 0x44},
   {0x2d, 0x00},
   {0x2e, 0x00},
   {0x2f, 0x80},
   {0x30, 0xbc},
   {0x31, 0xdf},
   {0x32, 0x02},
   {0x34, 0xcd},
   {0x35, 0xcc},
   {0x36, 0x3a},
   {0x38, 0x03},
   {0x39, 0x20},
   {0x3a, 0x00},
   {0x40, 0x00},
   {0x41, 0xff},
   {0x42, 0xff},
   {0x43, 0xff},
   {0x44, 0xff},
   {0x45, 0xff},
   {0x46, 0xff},
   {0x47, 0xff},
   {0x48, 0xff},
   {0x49, 0xff},
   {0x4a, 0xff},
   {0x4b, 0xff},
   {0x4c, 0xff},
   {0x4d, 0xff},
   {0x4e, 0xff},
   {0x4f, 0xff},
   {0x50, 0xff},
   {0x51, 0xff},
   {0x52, 0xff},
   {0x53, 0xff},
   {0x54, 0xff},
   {0x55, 0xff},
   {0x56, 0xff},
   {0x57, 0xff},
   {0x58, 0x00},
   {0x59, 0x47},
   {0x5a, 0x06},
   {0x5b, 0x03},
   {0x5c, 0x00},
   {0x5d, 0x00},
   {0x5e, 0x00},
   {0x5f, 0x00},
   {0x63, 0x00},
   {0x64, 0x00},
   {0x65, 0x00},
   {0x66, 0x00},
   {0x67, 0x00},
   {0x68, 0x00},
   {0x80, 0x10},
   {0x81, 0x00},
   {0x82, 0x00},
   {0x83, 0x01},
   {0x84, 0x20},
   {0x85, 0x04},
   {0x86, 0x45},
   {0x87, 0x01},
   {0x88, 0x38},
   {0x90, 0x41},
   {0x91, 0x08},
   {0x92, 0x00},
   {0x93, 0x00},
   {0x94, 0x05},
   {0x95, 0x00},
   {0x96, 0xd0},
   {0x97, 0x02},
   {0x98, 0x11},
   {0x99, 0x00},
   {0x9a, 0xf2},
   {0x9b, 0x00},
   {0x9c, 0xd0},
   {0x9d, 0x02},
   {0x9e, 0x50},
   {0x9f, 0x00},
   {0xa0, 0x04},
   {0xa1, 0x04},
   {0xa2, 0xfb},
   {0xa4, 0x80},
   {0xa5, 0x0f},
   {0xa6, 0x0e},
   {0xa8, 0x00},
   {0xa9, 0x04},
   {0xaa, 0x00},
   {0xac, 0x00},
   {0xad, 0x02},
   {0xae, 0x00},
   {0xb0, 0x00},
   {0xb1, 0x10},
   {0xb2, 0x00},
   {0xb3, 0x10},
   {0xb4, 0x01},
   {0xb8, 0x40},
   {0xb9, 0x00},
   {0xba, 0x50},
   {0xbb, 0x10},
   {0xbc, 0x40},
   {0xbd, 0x00},
   {0xbe, 0x50},
   {0xbf, 0x10},
   {0xc0, 0x00},
   {0xc1, 0x08},
   {0xc2, 0x00},
   {0xc3, 0x80},
   {0xc4, 0x3c},
   {0xc5, 0x00},
   {0xc6, 0xd0},
   {0xc7, 0x02},
   {0xc8, 0x00},
   {0xc9, 0x00},
   {0xca, 0x06},
   {0xcb, 0x01},
   {0xcc, 0xd0},
   {0xcd, 0x02},
   {0xce, 0x06},
   {0xcf, 0x01},
   {0xd0, 0x01},
   {0xd1, 0x00},
   {0xd2, 0x00},
   {0xd4, 0x80},
   {0xd5, 0x3f},
   {0xd6, 0x3f},
   {0xd8, 0x00},
   {0xd9, 0x04},
   {0xda, 0x00},
   {0xdc, 0x00},
   {0xdd, 0x02},
   {0xde, 0x00},
   {0xe0, 0x00},
   {0xe1, 0x04},
   {0xe2, 0x00},
   {0xe3, 0x04},
   {0xe4, 0x01},
   {0xe8, 0x00},
   {0xe9, 0x00},
   {0xea, 0x00},
   {0xeb, 0x00},
   {0xec, 0x00},
   {0xed, 0x00},
   {0xee, 0x00},
   {0xef, 0x00},
   {0x88, 0x28}
};

item ProgTable9[PROG_TBL9_SZ] = {
   /* Video decoder: front-end part */
   {0x01, 0x47},	/* increment delay */ 
   {0x02, 0xC0},  /* analog input control 1 */
   {0x03, 0x10},  /* analog input control 2 */
   {0x04, 0x90},  /* analog input control 3 */
   {0x05, 0x90},  /* analog input control 4 */
   /* Video decoder: decoder part */
   {0x06, 0xEB},  /* horizontal sync start  */
   {0x07, 0xE0},  /* horizontal sync stop   */
   {0x08, 0x98},  /* sync control           */
   {0x09, 0x40},  /* luminance control      */
   {0x0A, 0x80},  /* luminance brightness   */
   {0x0B, 0x44},  /* luminance contrast     */
   {0x0C, 0x40},  /* chrominance saturation */
   {0x0D, 0x00},  /* chrominance hue        */
   {0x0E, 0x89},  /* chrominance control 1  */
   {0x0F, 0x2A},  /* chrominance gain       */
   {0x10, 0x0E},  /* chrominance control 2  */
   {0x11, 0x00},  /* mode/delay control     */
   {0x12, 0x45},  /* RT signal control      */
   {0x13, 0x00},  /* RT/X-port out control  */
   {0x14, 0x10},  /* analog/ADC comp. ctrl  */
   {0x15, 0x11},  /* VGATE start            */
   {0x16, 0xFE},  /* VGATE stop             */
   {0x17, 0xD8},  /* VGATE control          */
   {0x18, 0x40},  /* raw data gain          */
   {0x19, 0x80},  /* raw data offset        */
   {0x1A, 0x00},  /* RESERVED               */
   {0x1B, 0x00},  /* RESERVED               */
   {0x1C, 0x00},  /* RESERVED               */
   {0x1D, 0x00},  /* RESERVED               */
   /* Component video part and interrupt mask */
   {0x20, 0x00},  /* RESERVED               */
   {0x21, 0x00},  /* RESERVED               */
   {0x22, 0x00},  /* RESERVED               */
   {0x23, 0x00},  /* analog input control 5 */
   {0x24, 0x90},  /* analog input control 6 */
   {0x25, 0x90},  /* analog input control 7 */
   {0x26, 0x00},  /* RESERVED               */
   {0x27, 0x00},  /* RESERVED               */
   {0x28, 0x00},  /* RESERVED               */
   {0x29, 0x00},  /* component delay        */
   {0x2A, 0x80},  /* comp brightness        */
   {0x2B, 0x40},  /* comp contrast          */
   {0x2C, 0x47},  /* comp saturation        */
   {0x2D, 0x00},  /* interrupt mask 1       */
   {0x2E, 0x00},  /* interrupt mask 2       */
   {0x2F, 0x00},  /* interrupt mask 3       */
   /* Audio clock generator */
   {0x30, 0xBC},  /* master clock cps 7-0   */
   {0x31, 0xDF},  /* master clock cps 15-8  */
   {0x32, 0x02},  /* master clock cps 17&16 */
   {0x34, 0xCD},  /* increment 7-0          */
   {0x35, 0xCC},  /* increment 15-8         */
   {0x36, 0x3A},  /* increment 17&16        */
   {0x38, 0x03},  /* ratio AMXCLK to ASCLK  */
   {0x39, 0x10},  /* ratio ASCLK to ALRCK   */
   {0x3A, 0x00},  /* setup                  */
   {0x3B, 0x00},  /* RESERVED               */
   {0x3C, 0x00},  /* RESERVED               */
   {0x3D, 0x00},  /* RESERVED               */
   {0x3E, 0x00},  /* RESERVED               */
   {0x3F, 0x00},  /* RESERVED               */
   /* VBI-data slicer */
   {0x40, 0x40},  /* slicer control 1       */
   {0x41, 0xFF},  /* line control reg 2     */
   {0x42, 0xFF},  /*                  3     */
   {0x43, 0xFF},  /*                  4     */
   {0x44, 0xFF},  /*                  5     */
   {0x45, 0xFF},  /*                  6     */
   {0x46, 0xFF},  /*                  7     */
   {0x47, 0xFF},  /*                  8     */
   {0x48, 0xFF},  /*                  9     */
   {0x49, 0xFF},  /*                  10    */
   {0x4A, 0xFF},  /*                  11    */
   {0x4B, 0xFF},  /*                  12    */
   {0x4C, 0xFF},  /*                  13    */
   {0x4D, 0xFF},  /*                  14    */
   {0x4E, 0xFF},  /*                  15    */
   {0x4F, 0xFF},  /*                  16    */
   {0x50, 0xFF},  /*                  17    */
   {0x51, 0xFF},  /*                  18    */
   {0x52, 0xFF},  /*                  19    */
   {0x53, 0xFF},  /*                  20    */
   {0x54, 0xFF},  /*                  21    */
   {0x55, 0xFF},  /*                  22    */
   {0x56, 0xFF},  /*                  23    */
   {0x57, 0xFF},  /* line control reg 24    */
   {0x58, 0x00},  /* prog framing code      */
   {0x59, 0x47},  /* horz offset            */
   {0x5A, 0x06},  /* vert offset            */
   {0x5B, 0x83},  /* field offset           */
   {0x5D, 0x3E},  /* ID code                */
   {0x5E, 0x00},  /* sliced data ID code    */
   {0x5F, 0x00},  /* RESERVED               */
   {0x63, 0x00},  /* RESERVED               */
   {0x64, 0x00},  /* RESERVED               */
   {0x65, 0x00},  /* RESERVED               */
   {0x66, 0x00},  /* RESERVED               */
   {0x67, 0x00},  /* RESERVED               */
   {0x68, 0x00},  /* RESERVED               */
   {0x69, 0x00},  /* RESERVED               */
   {0x6A, 0x00},  /* RESERVED               */
   {0x6B, 0x00},  /* RESERVED               */
   {0x6C, 0x00},  /* RESERVED               */
   {0x6D, 0x00},  /* RESERVED               */
   {0x6E, 0x00},  /* RESERVED               */
   {0x6F, 0x00},  /* RESERVED               */
   {0x70, 0x00},  /* RESERVED               */
   {0x71, 0x00},  /* RESERVED               */
   {0x72, 0x00},  /* RESERVED               */
   {0x73, 0x00},  /* RESERVED               */
   {0x74, 0x00},  /* RESERVED               */
   {0x75, 0x00},  /* RESERVED               */
   {0x76, 0x00},  /* RESERVED               */
   {0x77, 0x00},  /* RESERVED               */
   {0x78, 0x00},  /* RESERVED               */
   {0x79, 0x00},  /* RESERVED               */
   {0x7A, 0x00},  /* RESERVED               */
   {0x7B, 0x00},  /* RESERVED               */
   {0x7C, 0x00},  /* RESERVED               */
   {0x7D, 0x00},  /* RESERVED               */
   {0x7E, 0x00},  /* RESERVED               */
   {0x7F, 0x00},  /* RESERVED               */
   /* X-port, I-port, and Scaler: global */
   {0x80, 0x10},  /* task enable            */
   {0x81, 0x00},  /* RESERVED               */
   {0x82, 0x00},  /* RESERVED               */
   {0x83, 0x00},  /* output phase           */
   {0x84, 0xA0},  /* definition             */
   {0x85, 0x10},  /* swapping               */
   {0x86, 0x45},  /* arbitration            */
   {0x87, 0x01},  /* port enable            */
   {0x88, 0x38},  /* DPROG=1 digitize ADC1  */
   {0x89, 0x00},  /* RESERVED               */
   {0x8A, 0x00},  /* RESERVED               */
   {0x8B, 0x00},  /* RESERVED               */
   {0x8C, 0x00},  /* RESERVED               */
   {0x8D, 0x00},  /* RESERVED               */
   {0x8E, 0x00},  /* RESERVED               */
   /* Task A: scaler input/output */
   {0x90, 0x00},  /* task handling          */
   {0x91, 0x38},  /* scaler input format    */
   {0x92, 0x10},  /* reference signal       */
   {0x93, 0x84},  /* I-port output format   */
   /* Task A: window definition */
   {0x94, 0x10},  /* horz input offset      */
   {0x95, 0x00},
   {0x96, 0xD0},  /* horz input length      */
   {0x97, 0x02},
   {0x98, 0x0A},  /* vert input offset      */
   {0x99, 0x00},
   {0x9A, 0x22},  /* vert input length      */
   {0x9B, 0x01},
   {0x9C, 0xC8},  /* horz output length     */
   {0x9D, 0x00},
   {0x9E, 0x50},  /* vert output length     */
   {0x9F, 0x00},
   /* Task A: Prefiltering and prescaling */
   {0xA0, 0x02},  /* prescale               */
   {0xA1, 0x03},  /* accumulation length    */
   {0xA2, 0xF2},  /* prefilter              */
   {0xA3, 0x00},  /* RESERVED               */
   {0xA4, 0x80},  /* scaler brightness      */
   {0xA5, 0x11},  /* scaler contrast        */
   {0xA6, 0x11},  /* scaler satruation      */
   {0xA7, 0x00},  /* RESERVED               */
   /* Task A: horizontal phase scaling */
   {0xA8, 0x34},  /* horz lum scale         */
   {0xA9, 0x07},
   {0xAA, 0x00},  /* horz lum phase         */
   {0xAB, 0x00},  /* RESERVED               */
   {0xAC, 0x9A},  /* horz chrom increment   */
   {0xAD, 0x03},
   {0xAE, 0x00},  /* horz chrom phase       */
   {0xAF, 0x00},  /* RESERVED               */
   /* Task A: vertical scaling */
   {0xB0, 0x66},  /* vert lum inc           */
   {0xB1, 0x0E},
   {0xB2, 0x66},  /* vert chrom scaling     */
   {0xB3, 0x0E},
   {0xB4, 0x01},  /* vert scaling mode      */
   {0xB5, 0x00},  /* RESERVED               */
   {0xB6, 0x00},  /* RESERVED               */
   {0xB7, 0x00},  /* RESERVED               */
   {0xB8, 0x00},  /* vert phase offsets     */
   {0xB9, 0x00},
   {0xBA, 0x00},
   {0xBB, 0x00},
   {0xBC, 0x00},
   {0xBD, 0x00},
   {0xBE, 0x00},
   {0xBF, 0x00},
   {0xD3, 0x00},  /* RESERVED               */
   {0xD7, 0x00},  /* RESERVED               */
   {0xDB, 0x00},  /* RESERVED               */
   {0xDF, 0x00},  /* RESERVED               */
   {0xE5, 0x00},  /* RESERVED               */
   {0xE6, 0x00},  /* RESERVED               */
   {0xE7, 0x00},  /* RESERVED               */
   {0x88, 0x28}   /* DPROG=1 digitize ADC1  */
};

int main( int argc, char *argv[] )
{
   Csaa7118 VideoChip;
   int result;
   unsigned char index = 0;
   item *prog_tbl;
   int prog_tbl_sz;

   if( argc != 2 )
   {
      printf( "Usage: setup7118 <table number>\n" );
      printf( "       {table numbers 1 through 9}\n" );
   }
   else
   {
      switch( atoi(argv[1]) )
      {
         case 1:
            prog_tbl = ProgTable1;
            prog_tbl_sz = PROG_TBL1_SZ;
            break;
         case 2:
            prog_tbl = ProgTable2;
            prog_tbl_sz = PROG_TBL2_SZ;
            break;
         case 3:
            prog_tbl = ProgTable3;
            prog_tbl_sz = PROG_TBL3_SZ;
            break;
         case 4:
            prog_tbl = ProgTable4;
            prog_tbl_sz = PROG_TBL4_SZ;
            break;
         case 5:
            prog_tbl = ProgTable5;
            prog_tbl_sz = PROG_TBL5_SZ;
            break;
         case 6:
            prog_tbl = ProgTable6;
            prog_tbl_sz = PROG_TBL6_SZ;
            break;
         case 7:
            prog_tbl = ProgTable7;
            prog_tbl_sz = PROG_TBL7_SZ;
            break;
         case 8:
            prog_tbl = ProgTable8;
            prog_tbl_sz = PROG_TBL8_SZ;
            break;
         default:
            prog_tbl = ProgTable9;
            prog_tbl_sz = PROG_TBL9_SZ;
            break;
      }

      do
      {
         result = VideoChip.write( prog_tbl[index], 2 );
         if( result == 0 )
         {
            printf( "FAILED index: %i ", index );
            printf( "%X %X\n", prog_tbl[index][0], prog_tbl[index][1] );
            printf( "retry count: %i\n", VideoChip.RetryCount );
         }
         ++index;
      } while( index < prog_tbl_sz );
	}
   return 0;
}

